@@ -228,7 +228,9 @@ package Sidef::Deparse::Sidef {
             }
         }
         elsif ($ref eq 'Sidef::Types::Block::Next') {
-            $code = 'next';
+            if (not exists $expr->{call}) {
+                $code = 'next';
+            }
         }
         elsif ($ref eq 'Sidef::Types::Block::Continue') {
             $code = 'continue';
@@ -241,6 +243,9 @@ package Sidef::Deparse::Sidef {
         elsif ($ref eq 'Sidef::Math::Math') {
             $code = 'Math';
         }
+        elsif ($ref eq 'Sidef::Types::Glob::DirHandle') {
+            $code = 'DirHandle';
+        }
         elsif ($ref eq 'Sidef::Types::Glob::FileHandle') {
             if ($obj->{fh} eq \*STDIN) {
                 $code = 'STDIN';
@@ -457,8 +462,10 @@ package Sidef::Deparse::Sidef {
                 push @results, ref($expr) eq 'HASH' ? $self->deparse_expr($expr) : $self->deparse_expr({self => $expr});
             }
             if ($in_module) {
+                my $spaces = " " x $Sidef::SPACES_INCR;
+                s/^/$spaces/gm for @results;
                 $results[0] = "module $class {\n" . $results[0];
-                $results[-1] .= "\n}   # end of $class\n";
+                $results[-1] .= "\n}";
             }
         }
 
