@@ -7,38 +7,33 @@ package Sidef::Object::Object {
 
     # Logical AND
     *{__PACKAGE__ . '::' . '&&'} = sub {
-        my ($self, $code) = @_;
-        $self
-          ? Sidef::Types::Block::Code->new($code)->run
-          : $self;
+        $_[0]
+          ? Sidef::Types::Block::Code->new($_[1])->run
+          : $_[0];
     };
 
     # Logical OR
     *{__PACKAGE__ . '::' . '||'} = sub {
-        my ($self, $code) = @_;
-        $self
-          ? $self
-          : Sidef::Types::Block::Code->new($code)->run;
+        $_[0]
+          ? $_[0]
+          : Sidef::Types::Block::Code->new($_[1])->run;
     };
 
     # Logical XOR
     *{__PACKAGE__ . '::' . '^'} = sub {
-        my ($self, $val) = @_;
-        Sidef::Types::Bool::Bool->new($self xor $val);
+        Sidef::Types::Bool::Bool->new($_[0] xor $_[1]);
     };
 
     # Defined-OR
     *{__PACKAGE__ . '::' . '\\\\'} = sub {
-        my ($self, $code) = @_;
-        ref($self) eq 'Sidef::Types::Nil::Nil'
-          ? Sidef::Types::Block::Code->new($code)->run
-          : $self;
+        ref($_[0]) eq 'Sidef::Types::Nil::Nil'
+          ? Sidef::Types::Block::Code->new($_[1])->run
+          : $_[0];
     };
 
     # Ternary operator (Obj ? TrueExpr : FalseExpr)
     *{__PACKAGE__ . '::' . '?'} = sub {
-        my ($self, $code) = @_;
-        Sidef::Types::Bool::Ternary->new(code => $code, bool => !!$self);
+        Sidef::Types::Bool::Ternary->new(code => $_[1], bool => !!$_[0]);
     };
 
     # Smart match operator
@@ -94,7 +89,7 @@ package Sidef::Object::Object {
 
             # Array ~~ Array
             if ($s_type eq 'Sidef::Types::Array::Array') {
-                return $first->contains_all($second);
+                return $second->contains_all($first);
             }
 
             # Array ~~ Regex
@@ -104,7 +99,7 @@ package Sidef::Object::Object {
 
             # Array ~~ Hash
             if ($s_type eq 'Sidef::Types::Hash::Hash') {
-                return $second->keys->contains_any($first);
+                return $second->keys->contains_all($first);
             }
 
             # Array ~~ Any
@@ -116,12 +111,12 @@ package Sidef::Object::Object {
 
             # Hash ~~ Array
             if ($s_type eq 'Sidef::Types::Array::Array') {
-                return $first->keys->contains_all($second);
+                return $second->contains_all($first->keys);
             }
 
             # Hash ~~ Hash
             if ($s_type eq 'Sidef::Types::Hash::Hash') {
-                return $first->keys->contains_all($second->keys);
+                return $second->keys->contains_all($first->keys);
             }
 
             # Hash ~~ Any
@@ -157,10 +152,9 @@ package Sidef::Object::Object {
 
     # Negation of smart match
     *{__PACKAGE__ . '::' . '!~'} = sub {
-        my ($first, $second) = @_;
         use 5.014;
         state $method = '~~';
-        $first->$method($second)->not;
+        $_[0]->$method($_[1])->not;
     };
 };
 
