@@ -55,8 +55,6 @@ package Sidef::Types::Glob::File {
         Sidef::Types::Number::Number->new(File::Compare::compare($self->get_value, $file->get_value));
     }
 
-    *cmp = \&compare;
-
     sub exists {
         my ($self) = @_;
         @_ == 2 && ($self = $_[1]);
@@ -369,7 +367,7 @@ package Sidef::Types::Glob::File {
         my @lines;
         open(my $fh, '+<:utf8', $self->get_value) || return Sidef::Types::Bool::Bool->false;
         while (defined(my $line = <$fh>)) {
-            push @lines, $code->call(Sidef::Types::String::String->new($line));
+            push @lines, $code->run(Sidef::Types::String::String->new($line));
         }
 
         truncate($fh, 0) || do {
@@ -401,7 +399,7 @@ package Sidef::Types::Glob::File {
 
         my $success = CORE::open(my $fh, $mode, $self->get_value);
         my $error   = $!;
-        my $fh_obj  = Sidef::Types::Glob::FileHandle->new(fh => $fh, file => $self);
+        my $fh_obj  = Sidef::Types::Glob::FileHandle->new(fh => $fh, self => $self);
 
         if (defined $fh_ref) {
             $fh_ref->get_var->set_value($fh_obj);
@@ -464,7 +462,7 @@ package Sidef::Types::Glob::File {
         my $success = sysopen(my $fh, $self->get_value, $mode->get_value, defined($perm) ? $perm->get_value : 0666);
 
         if ($success) {
-            $var_ref->get_var->set_value(Sidef::Types::Glob::FileHandle->new(fh => $fh, file => $self));
+            $var_ref->get_var->set_value(Sidef::Types::Glob::FileHandle->new(fh => $fh, self => $self));
         }
 
         Sidef::Types::Bool::Bool->new($success);
@@ -543,11 +541,6 @@ package Sidef::Types::Glob::File {
     # Path split
     *split = \&Sidef::Types::Glob::Dir::split;
 
-    {
-        no strict 'refs';
-        *{__PACKAGE__ . '::' . '<=>'} = \&compare;
-    }
-
 };
 
 1
