@@ -508,7 +508,7 @@ package Sidef::Types::String::String {
             return __PACKAGE__->new($self->get_value =~ s{$search}{$code->get_value}eer);
         }
 
-        __PACKAGE__->new($self->get_value =~ s{$search}{$code->call(_get_captures($self->get_value))}er);
+        __PACKAGE__->new($self->get_value =~ s{$search}{$code->run(_get_captures($self->get_value))}er);
     }
 
     sub gesub {
@@ -526,7 +526,7 @@ package Sidef::Types::String::String {
         }
 
         my $value = $self->get_value;
-        __PACKAGE__->new($value =~ s{$search}{$code->call(_get_captures($value))}ger);
+        __PACKAGE__->new($value =~ s{$search}{$code->run(_get_captures($value))}ger);
     }
 
     sub glob {
@@ -746,6 +746,33 @@ package Sidef::Types::String::String {
     *graphemes    = \&graphs;
     *to_graphemes = \&graphs;
 
+    sub levenshtein {
+        my ($self, $arg) = @_;
+
+        my @s = split(//, $self->get_value);
+        my @t = split(//, $arg->get_value);
+
+        my $len1 = scalar(@s);
+        my $len2 = scalar(@t);
+
+        state $x = require List::Util;
+
+        my @d = ([0 .. $len2], map { [$_] } 1 .. $len1);
+        foreach my $i (1 .. $len1) {
+            foreach my $j (1 .. $len2) {
+                $d[$i][$j] =
+                    $s[$i - 1] eq $t[$j - 1]
+                  ? $d[$i - 1][$j - 1]
+                  : List::Util::min($d[$i - 1][$j], $d[$i][$j - 1], $d[$i - 1][$j - 1]) + 1;
+            }
+        }
+
+        Sidef::Types::Number::Number->new($d[-1][-1]);
+    }
+
+    *lev   = \&levenshtein;
+    *leven = \&levenshtein;
+
     sub contains {
         my ($self, $string, $start_pos) = @_;
 
@@ -1138,8 +1165,6 @@ package Sidef::Types::String::String {
         *{__PACKAGE__ . '::' . '^'}   = \&xor;
         *{__PACKAGE__ . '::' . '|'}   = \&or;
         *{__PACKAGE__ . '::' . '&'}   = \&and;
-        *{__PACKAGE__ . '::' . '^^'}  = \&begins_with;
-        *{__PACKAGE__ . '::' . '$$'}  = \&ends_with;
         *{__PACKAGE__ . '::' . '<<'}  = \&shift_left;
         *{__PACKAGE__ . '::' . '>>'}  = \&shift_right;
         *{__PACKAGE__ . '::' . '%'}   = \&sprintf;
